@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2005 Joe Walnes.
- * Copyright (C) 2006, 2007 XStream Committers.
+ * Copyright (C) 2006, 2007, 2008 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -17,6 +17,7 @@
 package com.thoughtworks.xstream.converters.enums;
 
 import com.thoughtworks.xstream.converters.collections.MapConverter;
+import com.thoughtworks.xstream.converters.ConversionException;
 import com.thoughtworks.xstream.converters.MarshallingContext;
 import com.thoughtworks.xstream.converters.UnmarshallingContext;
 import com.thoughtworks.xstream.mapper.Mapper;
@@ -63,12 +64,19 @@ public class EnumMapConverter extends MapConverter {
 
     public void marshal(Object source, HierarchicalStreamWriter writer, MarshallingContext context) {
         Class type = (Class) Fields.read(typeField, source);
-        writer.addAttribute(mapper().aliasForAttribute("enum-type"), mapper().serializedClass(type));
+        String attributeName = mapper().aliasForSystemAttribute("enum-type");
+        if (attributeName != null) {
+            writer.addAttribute(attributeName, mapper().serializedClass(type));
+        }
         super.marshal(source, writer, context);
     }
 
     public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context) {
-        Class type = mapper().realClass(reader.getAttribute(mapper().aliasForAttribute("enum-type")));
+        String attributeName = mapper().aliasForSystemAttribute("enum-type");
+        if (attributeName == null) {
+            throw new ConversionException("No EnumType specified for EnumMap");
+        }
+        Class type = mapper().realClass(reader.getAttribute(attributeName));
         EnumMap map = new EnumMap(type);
         populateMap(reader, context, map);
         return map;
