@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2004 Joe Walnes.
- * Copyright (C) 2006, 2007 XStream Committers.
+ * Copyright (C) 2006, 2007, 2008 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -16,17 +16,19 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 
+
 /**
  * Store IDs against given object references.
  * <p>
- * Behaves similar to java.util.IdentityHashMap, but in JDK1.3 as well. Additionally the implementation
- * keeps track of orphaned IDs by using a WeakReference to store the reference object.
+ * Behaves similar to java.util.IdentityHashMap, but in JDK1.3 as well. Additionally the
+ * implementation keeps track of orphaned IDs by using a WeakReference to store the reference
+ * object.
  * </p>
  */
 public class ObjectIdDictionary {
 
     private final Map map = new HashMap();
-    private int invalidCounter;
+    private volatile int counter;
 
     private static interface Wrapper {
         int hashCode();
@@ -34,17 +36,19 @@ public class ObjectIdDictionary {
         String toString();
         Object get();
     }
-    
+
     private static class IdWrapper implements Wrapper {
 
         private final Object obj;
+        private final int hashCode;
 
         public IdWrapper(Object obj) {
+            hashCode = System.identityHashCode(obj);
             this.obj = obj;
         }
 
         public int hashCode() {
-            return System.identityHashCode(obj);
+            return hashCode;
         }
 
         public boolean equals(Object other) {
@@ -54,13 +58,13 @@ public class ObjectIdDictionary {
         public String toString() {
             return obj.toString();
         }
-        
+
         public Object get() {
             return obj;
         }
     }
 
-    private class WeakIdWrapper implements Wrapper {
+    private static class WeakIdWrapper implements Wrapper {
 
         private final int hashCode;
         private final WeakReference ref;
@@ -82,46 +86,44 @@ public class ObjectIdDictionary {
             Object obj = get();
             return obj == null ? "(null)" : obj.toString();
         }
-        
+
         public Object get() {
             Object obj = ref.get();
-            if (obj == null) {
-                // it was a lot faster and more efficient simply to count the number of
-                // evidences instead of keeping the Wrapper somewhere in a remove list
-                ++ObjectIdDictionary.this.invalidCounter;
-            }
             return obj;
         }
     }
 
     public void associateId(Object obj, Object id) {
         map.put(new WeakIdWrapper(obj), id);
+        ++counter;
         cleanup();
     }
 
     public Object lookupId(Object obj) {
         Object id = map.get(new IdWrapper(obj));
-        cleanup();
+        ++counter;
         return id;
     }
 
     public boolean containsId(Object item) {
         boolean b = map.containsKey(new IdWrapper(item));
-        cleanup();
+        ++counter;
         return b;
     }
 
     public void removeId(Object item) {
         map.remove(new IdWrapper(item));
+        ++counter;
         cleanup();
     }
-    
+
     public int size() {
         return map.size();
     }
 
     private void cleanup() {
-        if (invalidCounter > 100) {
+        if (counter > 10000) {
+            counter = 0;
             // much more efficient to remove any orphaned wrappers at once
             for (final Iterator iterator = map.keySet().iterator(); iterator.hasNext();) {
                 final WeakIdWrapper key = (WeakIdWrapper)iterator.next();
@@ -129,7 +131,6 @@ public class ObjectIdDictionary {
                     iterator.remove();
                 }
             }
-            invalidCounter = 0;
         }
     }
 }
