@@ -21,7 +21,7 @@ import javax.xml.stream.XMLStreamWriter;
  * A stream writing that outputs to a StAX stream writer
  *
  * @author James Strachan
- * @version $Revision: 1388 $
+ * @version $Revision: 1466 $
  */
 public class StaxWriter extends AbstractXmlWriter {
     
@@ -182,4 +182,12 @@ public class StaxWriter extends AbstractXmlWriter {
         return namespaceRepairingMode;
     }
 
+    protected QNameMap getQNameMap() {
+        return this.qnameMap;
+    }
+
+    protected XMLStreamWriter getXMLStreamWriter() {
+        return this.out;
+    }
+
 }
